Bioamla Modules
===============

The bioamla package contains the main functionality for bioacoustics processing and machine learning.

.. automodule:: bioamla
   :members:
   :undoc-members:
   :show-inheritance:

AST (Audio Spectrogram Transformer)
-----------------------------------

.. automodule:: bioamla.ast
   :members:
   :undoc-members:
   :show-inheritance:

Datasets
--------

.. automodule:: bioamla.datasets
   :members:
   :undoc-members:
   :show-inheritance:

Training
--------

.. automodule:: bioamla.training
   :members:
   :undoc-members:
   :show-inheritance:

Inference
---------

.. automodule:: bioamla.inference
   :members:
   :undoc-members:
   :show-inheritance:

Evaluation
----------

.. automodule:: bioamla.evaluate
   :members:
   :undoc-members:
   :show-inheritance:

Signal Processing
-----------------

.. automodule:: bioamla.signal
   :members:
   :undoc-members:
   :show-inheritance:

Visualization
-------------

.. automodule:: bioamla.visualize
   :members:
   :undoc-members:
   :show-inheritance:

Augmentation
------------

.. automodule:: bioamla.augment
   :members:
   :undoc-members:
   :show-inheritance:

Device Utilities
----------------

.. automodule:: bioamla.device
   :members:
   :undoc-members:
   :show-inheritance:

File Utilities
--------------

.. automodule:: bioamla.fileutils
   :members:
   :undoc-members:
   :show-inheritance:

Logging
-------

.. automodule:: bioamla.logging
   :members:
   :undoc-members:
   :show-inheritance:

Metadata
--------

.. automodule:: bioamla.metadata
   :members:
   :undoc-members:
   :show-inheritance:

iNaturalist Integration
-----------------------

.. automodule:: bioamla.inat
   :members:
   :undoc-members:
   :show-inheritance:

Wildlife Acoustics
------------------

.. automodule:: bioamla.wildlife_acoustics
   :members:
   :undoc-members:
   :show-inheritance:
